@@ -25,8 +25,6 @@ export const simpleUpdateModels = [
   'CertificateNotification',
   'DeathRevertLog',
   'UserRecentlyViewedPatient',
-  'PatientProgramRegistration',
-  'PatientProgramRegistrationCondition',
   'PatientContact',
   'IPSRequest',
   'Notification',
@@ -38,6 +36,8 @@ export const simpleUpdateModels = [
 export const specificUpdateModels = [
   'Patient',
   'PatientAdditionalData',
+  'PatientProgramRegistration',
+  'PatientProgramRegistrationCondition',
   'PatientBirthData',
   'PatientDeathData',
   'Note',
@@ -82,7 +82,7 @@ function getMergedFieldsForUpdate(keepRecordValues = {}, unwantedRecordValues =
   };
 }
 
-const fieldReferencesPatient = field => field.references?.model === 'patients';
+const fieldReferencesPatient = (field) => field.references?.model === 'patients';
 const modelReferencesPatient = ([, model]) =>
   Object.values(model.getAttributes()).some(fieldReferencesPatient);
 
@@ -213,6 +213,62 @@ export async function mergePatientDeathData(models, keepPatientId, unwantedPatie
   return results;
 }
 
+export async function mergePatientProgramRegistrations(models, keepPatientId, unwantedPatientId) {
+  const existingUnwantedRegistrations = await models.PatientProgramRegistration.findAll({
+    where: { patientId: unwantedPatientId },
+  });
+
+  if (!existingUnwantedRegistrations.length) {
+    return [];
+  }
+
+  const results = [];
+
+  for (const unwantedRegistration of existingUnwantedRegistrations) {
+    // Move to keep patient and reset isMostRecent to false
+    await unwantedRegistration.update({
+      patientId: keepPatientId,
+      isMostRecent: false,
+    });
+
+    // Soft delete the registration
+    await unwantedRegistration.destroy();
+    results.push(unwantedRegistration);
+  }
+
+  return results;
+}
+
+export async function mergePatientProgramRegistrationConditions(
+  models,
+  keepPatientId,
+  unwantedPatientId,
+) {
+  const existingUnwantedRegistrationConditions =
+    await models.PatientProgramRegistrationCondition.findAll({
+      where: { patientId: unwantedPatientId },
+    });
+
+  if (!existingUnwantedRegistrationConditions.length) {
+    return [];
+  }
+
+  const results = [];
+
+  for (const unwantedCondition of existingUnwantedRegistrationConditions) {
+    // Move to keep patient
+    await unwantedCondition.update({
+      patientId: keepPatientId,
+    });
+
+    // Soft delete the registration
+    await unwantedCondition.destroy();
+    results.push(unwantedCondition);
+  }
+
+  return results;
+}
+
 export async function mergePatientFieldValues(models, keepPatientId, unwantedPatientId) {
   const existingUnwantedFieldValues = await models.PatientFieldValue.findAll({
     where: { patientId: unwantedPatientId },
@@ -276,9 +332,9 @@ export async function reconcilePatientFacilities(models, keepPatientId, unwanted
   if (existingPatientFacilityRecords.length === 0) return [];
 
   const facilitiesTrackingPatient = [
-    ...new Set(existingPatientFacilityRecords.map(r => r.facilityId)),
+    ...new Set(existingPatientFacilityRecords.map((r) => r.facilityId)),
   ];
-  const newPatientFacilities = facilitiesTrackingPatient.map(facilityId => ({
+  const newPatientFacilities = facilitiesTrackingPatient.map((facilityId) => ({
     patientId: keepPatientId,
     facilityId,
   }));
@@ -375,6 +431,22 @@ export async function mergePatient(models, keepPatientId, unwantedPatientId) {
       updates.PatientFieldValue = fieldValueUpdates.length;
     }
 
+    const patientProgramRegistrationUpdates = await mergePatientProgramRegistrations(
+      models,
+      keepPatientId,
+      unwantedPatientId,
+    );
+    if (patientProgramRegistrationUpdates.length > 0) {
+      updates.PatientProgramRegistration = patientProgramRegistrationUpdates.length;
+    }
+
+    const patientProgramRegistrationConditionUpdates =
+      await mergePatientProgramRegistrationConditions(models, keepPatientId, unwantedPatientId);
+    if (patientProgramRegistrationConditionUpdates.length > 0) {
+      updates.PatientProgramRegistrationCondition =
+        patientProgramRegistrationConditionUpdates.length;
+    }
+
     // Merge notes - these don't have a patient_id due to their polymorphic FK setup
     // so need to be handled slightly differently.
     const notesMerged = await mergeRecordsForModel(
