@@ -1,9 +1,12 @@
+import { REFERENCE_TYPES } from '@tamanu/constants';
 import {
   administeredVaccineLoader,
   labTestPanelLoader,
   patientDataLoader,
   patientFieldDefinitionLoader,
   permissionLoader,
+  taskTemplateLoader,
+  taskSetLoader,
   translatedStringLoader,
   userLoader,
 } from './loaders';
@@ -78,4 +81,12 @@ export default {
   },
 
   referenceDataRelation: {},
+
+  [REFERENCE_TYPES.TASK_TEMPLATE]: {
+    loader: taskTemplateLoader
+  },
+
+  [REFERENCE_TYPES.TASK_SET]: {
+    loader: taskSetLoader,
+  },
 };
